@@ -197,17 +197,17 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_efs
-import aws_cdk.aws_events
-import aws_cdk.aws_iam
-import aws_cdk.aws_lambda
-import aws_cdk.aws_s3
-import aws_cdk.aws_sqs
-import constructs
+import aws_cdk.aws_efs as _aws_cdk_aws_efs_ceddda9d
+import aws_cdk.aws_events as _aws_cdk_aws_events_ceddda9d
+import aws_cdk.aws_iam as _aws_cdk_aws_iam_ceddda9d
+import aws_cdk.aws_lambda as _aws_cdk_aws_lambda_ceddda9d
+import aws_cdk.aws_s3 as _aws_cdk_aws_s3_ceddda9d
+import aws_cdk.aws_sqs as _aws_cdk_aws_sqs_ceddda9d
+import constructs as _constructs_77d1e7e8
 
 
 class ServerlessClamscan(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="cdk-serverless-clamscan.ServerlessClamscan",
 ):
@@ -244,16 +244,16 @@ class ServerlessClamscan(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         accept_responsibility_for_using_imported_bucket: typing.Optional[builtins.bool] = None,
-        buckets: typing.Optional[typing.Sequence[aws_cdk.aws_s3.IBucket]] = None,
-        defs_bucket_access_logs_config: typing.Optional[typing.Union["ServerlessClamscanLoggingProps", typing.Dict[str, typing.Any]]] = None,
+        buckets: typing.Optional[typing.Sequence[_aws_cdk_aws_s3_ceddda9d.IBucket]] = None,
+        defs_bucket_access_logs_config: typing.Optional[typing.Union["ServerlessClamscanLoggingProps", typing.Dict[builtins.str, typing.Any]]] = None,
         efs_encryption: typing.Optional[builtins.bool] = None,
-        efs_performance_mode: typing.Optional[aws_cdk.aws_efs.PerformanceMode] = None,
-        on_error: typing.Optional[aws_cdk.aws_lambda.IDestination] = None,
-        on_result: typing.Optional[aws_cdk.aws_lambda.IDestination] = None,
+        efs_performance_mode: typing.Optional[_aws_cdk_aws_efs_ceddda9d.PerformanceMode] = None,
+        on_error: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.IDestination] = None,
+        on_result: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.IDestination] = None,
         reserved_concurrency: typing.Optional[jsii.Number] = None,
         scan_function_memory_size: typing.Optional[jsii.Number] = None,
     ) -> None:
@@ -272,22 +272,7 @@ class ServerlessClamscan(
         :param scan_function_memory_size: Optionally set the memory allocation for the scan function. Note that low memory allocations may cause errors. (Default: 10240).
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                accept_responsibility_for_using_imported_bucket: typing.Optional[builtins.bool] = None,
-                buckets: typing.Optional[typing.Sequence[aws_cdk.aws_s3.IBucket]] = None,
-                defs_bucket_access_logs_config: typing.Optional[typing.Union[ServerlessClamscanLoggingProps, typing.Dict[str, typing.Any]]] = None,
-                efs_encryption: typing.Optional[builtins.bool] = None,
-                efs_performance_mode: typing.Optional[aws_cdk.aws_efs.PerformanceMode] = None,
-                on_error: typing.Optional[aws_cdk.aws_lambda.IDestination] = None,
-                on_result: typing.Optional[aws_cdk.aws_lambda.IDestination] = None,
-                reserved_concurrency: typing.Optional[jsii.Number] = None,
-                scan_function_memory_size: typing.Optional[jsii.Number] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__ed8d91de6d3b1d3b5b25b039320198cf5ad1c0f9205948695f5a09421a986084)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ServerlessClamscanProps(
@@ -305,7 +290,7 @@ class ServerlessClamscan(
         jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="addSourceBucket")
-    def add_source_bucket(self, bucket: aws_cdk.aws_s3.IBucket) -> None:
+    def add_source_bucket(self, bucket: _aws_cdk_aws_s3_ceddda9d.IBucket) -> None:
         '''Sets the specified S3 Bucket as a s3:ObjectCreate* for the ClamAV function.
 
         Grants the ClamAV function permissions to get and tag objects.
@@ -314,17 +299,15 @@ class ServerlessClamscan(
         :param bucket: The bucket to add the scanning bucket policy and s3:ObjectCreate* trigger to.
         '''
         if __debug__:
-            def stub(bucket: aws_cdk.aws_s3.IBucket) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__3e814dc0b4006f620db601182ab2e1605421bf11a1ddd8d6862a3542134d7568)
             check_type(argname="argument bucket", value=bucket, expected_type=type_hints["bucket"])
         return typing.cast(None, jsii.invoke(self, "addSourceBucket", [bucket]))
 
     @jsii.member(jsii_name="getPolicyStatementForBucket")
     def get_policy_statement_for_bucket(
         self,
-        bucket: aws_cdk.aws_s3.IBucket,
-    ) -> aws_cdk.aws_iam.PolicyStatement:
+        bucket: _aws_cdk_aws_s3_ceddda9d.IBucket,
+    ) -> _aws_cdk_aws_iam_ceddda9d.PolicyStatement:
         '''Returns the statement that should be added to the bucket policy in order to prevent objects to be accessed when they are not clean or there have been scanning errors: this policy should be added manually if external buckets are passed to addSourceBucket().
 
         :param bucket: The bucket which you need to protect with the policy.
@@ -332,67 +315,69 @@ class ServerlessClamscan(
         :return: PolicyStatement the policy statement if available
         '''
         if __debug__:
-            def stub(bucket: aws_cdk.aws_s3.IBucket) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__7810beb50932b9b83ee8c63bc62209567de654d2032fafbe7348d1b7415fa413)
             check_type(argname="argument bucket", value=bucket, expected_type=type_hints["bucket"])
-        return typing.cast(aws_cdk.aws_iam.PolicyStatement, jsii.invoke(self, "getPolicyStatementForBucket", [bucket]))
+        return typing.cast(_aws_cdk_aws_iam_ceddda9d.PolicyStatement, jsii.invoke(self, "getPolicyStatementForBucket", [bucket]))
 
     @builtins.property
     @jsii.member(jsii_name="errorDest")
-    def error_dest(self) -> aws_cdk.aws_lambda.IDestination:
+    def error_dest(self) -> _aws_cdk_aws_lambda_ceddda9d.IDestination:
         '''The Lambda Destination for failed on erred scans [ERROR, IN PROGRESS (If error is due to Lambda timeout)].'''
-        return typing.cast(aws_cdk.aws_lambda.IDestination, jsii.get(self, "errorDest"))
+        return typing.cast(_aws_cdk_aws_lambda_ceddda9d.IDestination, jsii.get(self, "errorDest"))
 
     @builtins.property
     @jsii.member(jsii_name="resultDest")
-    def result_dest(self) -> aws_cdk.aws_lambda.IDestination:
+    def result_dest(self) -> _aws_cdk_aws_lambda_ceddda9d.IDestination:
         '''The Lambda Destination for completed ClamAV scans [CLEAN, INFECTED].'''
-        return typing.cast(aws_cdk.aws_lambda.IDestination, jsii.get(self, "resultDest"))
+        return typing.cast(_aws_cdk_aws_lambda_ceddda9d.IDestination, jsii.get(self, "resultDest"))
 
     @builtins.property
     @jsii.member(jsii_name="scanAssumedPrincipal")
-    def scan_assumed_principal(self) -> aws_cdk.aws_iam.ArnPrincipal:
+    def scan_assumed_principal(self) -> _aws_cdk_aws_iam_ceddda9d.ArnPrincipal:
         '''
         :return: ArnPrincipal the ARN of the assumed role principal for the scan function
         '''
-        return typing.cast(aws_cdk.aws_iam.ArnPrincipal, jsii.get(self, "scanAssumedPrincipal"))
+        return typing.cast(_aws_cdk_aws_iam_ceddda9d.ArnPrincipal, jsii.get(self, "scanAssumedPrincipal"))
 
     @builtins.property
     @jsii.member(jsii_name="cleanRule")
-    def clean_rule(self) -> typing.Optional[aws_cdk.aws_events.Rule]:
+    def clean_rule(self) -> typing.Optional[_aws_cdk_aws_events_ceddda9d.Rule]:
         '''Conditional: An Event Bridge Rule for files that are marked 'CLEAN' by ClamAV if a success destination was not specified.'''
-        return typing.cast(typing.Optional[aws_cdk.aws_events.Rule], jsii.get(self, "cleanRule"))
+        return typing.cast(typing.Optional[_aws_cdk_aws_events_ceddda9d.Rule], jsii.get(self, "cleanRule"))
 
     @builtins.property
     @jsii.member(jsii_name="defsAccessLogsBucket")
-    def defs_access_logs_bucket(self) -> typing.Optional[aws_cdk.aws_s3.IBucket]:
+    def defs_access_logs_bucket(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_s3_ceddda9d.IBucket]:
         '''Conditional: The Bucket for access logs for the virus definitions bucket if logging is enabled (defsBucketAccessLogsConfig).'''
-        return typing.cast(typing.Optional[aws_cdk.aws_s3.IBucket], jsii.get(self, "defsAccessLogsBucket"))
+        return typing.cast(typing.Optional[_aws_cdk_aws_s3_ceddda9d.IBucket], jsii.get(self, "defsAccessLogsBucket"))
 
     @builtins.property
     @jsii.member(jsii_name="errorDeadLetterQueue")
-    def error_dead_letter_queue(self) -> typing.Optional[aws_cdk.aws_sqs.Queue]:
+    def error_dead_letter_queue(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_sqs_ceddda9d.Queue]:
         '''Conditional: The SQS Dead Letter Queue for the errorQueue if a failure (onError) destination was not specified.'''
-        return typing.cast(typing.Optional[aws_cdk.aws_sqs.Queue], jsii.get(self, "errorDeadLetterQueue"))
+        return typing.cast(typing.Optional[_aws_cdk_aws_sqs_ceddda9d.Queue], jsii.get(self, "errorDeadLetterQueue"))
 
     @builtins.property
     @jsii.member(jsii_name="errorQueue")
-    def error_queue(self) -> typing.Optional[aws_cdk.aws_sqs.Queue]:
+    def error_queue(self) -> typing.Optional[_aws_cdk_aws_sqs_ceddda9d.Queue]:
         '''Conditional: The SQS Queue for erred scans if a failure (onError) destination was not specified.'''
-        return typing.cast(typing.Optional[aws_cdk.aws_sqs.Queue], jsii.get(self, "errorQueue"))
+        return typing.cast(typing.Optional[_aws_cdk_aws_sqs_ceddda9d.Queue], jsii.get(self, "errorQueue"))
 
     @builtins.property
     @jsii.member(jsii_name="infectedRule")
-    def infected_rule(self) -> typing.Optional[aws_cdk.aws_events.Rule]:
+    def infected_rule(self) -> typing.Optional[_aws_cdk_aws_events_ceddda9d.Rule]:
         '''Conditional: An Event Bridge Rule for files that are marked 'INFECTED' by ClamAV if a success destination was not specified.'''
-        return typing.cast(typing.Optional[aws_cdk.aws_events.Rule], jsii.get(self, "infectedRule"))
+        return typing.cast(typing.Optional[_aws_cdk_aws_events_ceddda9d.Rule], jsii.get(self, "infectedRule"))
 
     @builtins.property
     @jsii.member(jsii_name="resultBus")
-    def result_bus(self) -> typing.Optional[aws_cdk.aws_events.EventBus]:
+    def result_bus(self) -> typing.Optional[_aws_cdk_aws_events_ceddda9d.EventBus]:
         '''Conditional: The Event Bridge Bus for completed ClamAV scans if a success (onResult) destination was not specified.'''
-        return typing.cast(typing.Optional[aws_cdk.aws_events.EventBus], jsii.get(self, "resultBus"))
+        return typing.cast(typing.Optional[_aws_cdk_aws_events_ceddda9d.EventBus], jsii.get(self, "resultBus"))
 
     @builtins.property
     @jsii.member(jsii_name="useImportedBuckets")
@@ -410,7 +395,7 @@ class ServerlessClamscanLoggingProps:
     def __init__(
         self,
         *,
-        logs_bucket: typing.Optional[typing.Union[builtins.bool, aws_cdk.aws_s3.IBucket]] = None,
+        logs_bucket: typing.Optional[typing.Union[builtins.bool, _aws_cdk_aws_s3_ceddda9d.IBucket]] = None,
         logs_prefix: typing.Optional[builtins.str] = None,
     ) -> None:
         '''Interface for ServerlessClamscan Virus Definitions S3 Bucket Logging.
@@ -419,16 +404,10 @@ class ServerlessClamscanLoggingProps:
         :param logs_prefix: Optional log file prefix to use for the bucket's access logs, option is ignored if logs_bucket is set to false.
         '''
         if __debug__:
-            def stub(
-                *,
-                logs_bucket: typing.Optional[typing.Union[builtins.bool, aws_cdk.aws_s3.IBucket]] = None,
-                logs_prefix: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__c6710eb9eef2e9b05a93d9fba80fbf988499356d748d843afa0ab4772c40b9a4)
             check_type(argname="argument logs_bucket", value=logs_bucket, expected_type=type_hints["logs_bucket"])
             check_type(argname="argument logs_prefix", value=logs_prefix, expected_type=type_hints["logs_prefix"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if logs_bucket is not None:
             self._values["logs_bucket"] = logs_bucket
         if logs_prefix is not None:
@@ -437,10 +416,10 @@ class ServerlessClamscanLoggingProps:
     @builtins.property
     def logs_bucket(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, aws_cdk.aws_s3.IBucket]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _aws_cdk_aws_s3_ceddda9d.IBucket]]:
         '''Destination bucket for the server access logs (Default: Creates a new S3 Bucket for access logs).'''
         result = self._values.get("logs_bucket")
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, aws_cdk.aws_s3.IBucket]], result)
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _aws_cdk_aws_s3_ceddda9d.IBucket]], result)
 
     @builtins.property
     def logs_prefix(self) -> typing.Optional[builtins.str]:
@@ -480,12 +459,12 @@ class ServerlessClamscanProps:
         self,
         *,
         accept_responsibility_for_using_imported_bucket: typing.Optional[builtins.bool] = None,
-        buckets: typing.Optional[typing.Sequence[aws_cdk.aws_s3.IBucket]] = None,
-        defs_bucket_access_logs_config: typing.Optional[typing.Union[ServerlessClamscanLoggingProps, typing.Dict[str, typing.Any]]] = None,
+        buckets: typing.Optional[typing.Sequence[_aws_cdk_aws_s3_ceddda9d.IBucket]] = None,
+        defs_bucket_access_logs_config: typing.Optional[typing.Union[ServerlessClamscanLoggingProps, typing.Dict[builtins.str, typing.Any]]] = None,
         efs_encryption: typing.Optional[builtins.bool] = None,
-        efs_performance_mode: typing.Optional[aws_cdk.aws_efs.PerformanceMode] = None,
-        on_error: typing.Optional[aws_cdk.aws_lambda.IDestination] = None,
-        on_result: typing.Optional[aws_cdk.aws_lambda.IDestination] = None,
+        efs_performance_mode: typing.Optional[_aws_cdk_aws_efs_ceddda9d.PerformanceMode] = None,
+        on_error: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.IDestination] = None,
+        on_result: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.IDestination] = None,
         reserved_concurrency: typing.Optional[jsii.Number] = None,
         scan_function_memory_size: typing.Optional[jsii.Number] = None,
     ) -> None:
@@ -504,20 +483,7 @@ class ServerlessClamscanProps:
         if isinstance(defs_bucket_access_logs_config, dict):
             defs_bucket_access_logs_config = ServerlessClamscanLoggingProps(**defs_bucket_access_logs_config)
         if __debug__:
-            def stub(
-                *,
-                accept_responsibility_for_using_imported_bucket: typing.Optional[builtins.bool] = None,
-                buckets: typing.Optional[typing.Sequence[aws_cdk.aws_s3.IBucket]] = None,
-                defs_bucket_access_logs_config: typing.Optional[typing.Union[ServerlessClamscanLoggingProps, typing.Dict[str, typing.Any]]] = None,
-                efs_encryption: typing.Optional[builtins.bool] = None,
-                efs_performance_mode: typing.Optional[aws_cdk.aws_efs.PerformanceMode] = None,
-                on_error: typing.Optional[aws_cdk.aws_lambda.IDestination] = None,
-                on_result: typing.Optional[aws_cdk.aws_lambda.IDestination] = None,
-                reserved_concurrency: typing.Optional[jsii.Number] = None,
-                scan_function_memory_size: typing.Optional[jsii.Number] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__bcf16e4cfa40d24a942937d7d5ee19975f275f2c96366670b2ec79ce3f1a2213)
             check_type(argname="argument accept_responsibility_for_using_imported_bucket", value=accept_responsibility_for_using_imported_bucket, expected_type=type_hints["accept_responsibility_for_using_imported_bucket"])
             check_type(argname="argument buckets", value=buckets, expected_type=type_hints["buckets"])
             check_type(argname="argument defs_bucket_access_logs_config", value=defs_bucket_access_logs_config, expected_type=type_hints["defs_bucket_access_logs_config"])
@@ -527,7 +493,7 @@ class ServerlessClamscanProps:
             check_type(argname="argument on_result", value=on_result, expected_type=type_hints["on_result"])
             check_type(argname="argument reserved_concurrency", value=reserved_concurrency, expected_type=type_hints["reserved_concurrency"])
             check_type(argname="argument scan_function_memory_size", value=scan_function_memory_size, expected_type=type_hints["scan_function_memory_size"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if accept_responsibility_for_using_imported_bucket is not None:
             self._values["accept_responsibility_for_using_imported_bucket"] = accept_responsibility_for_using_imported_bucket
         if buckets is not None:
@@ -559,13 +525,13 @@ class ServerlessClamscanProps:
         return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
-    def buckets(self) -> typing.Optional[typing.List[aws_cdk.aws_s3.IBucket]]:
+    def buckets(self) -> typing.Optional[typing.List[_aws_cdk_aws_s3_ceddda9d.IBucket]]:
         '''An optional list of S3 buckets to configure for ClamAV Virus Scanning;
 
         buckets can be added later by calling addSourceBucket.
         '''
         result = self._values.get("buckets")
-        return typing.cast(typing.Optional[typing.List[aws_cdk.aws_s3.IBucket]], result)
+        return typing.cast(typing.Optional[typing.List[_aws_cdk_aws_s3_ceddda9d.IBucket]], result)
 
     @builtins.property
     def defs_bucket_access_logs_config(
@@ -582,22 +548,24 @@ class ServerlessClamscanProps:
         return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
-    def efs_performance_mode(self) -> typing.Optional[aws_cdk.aws_efs.PerformanceMode]:
+    def efs_performance_mode(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_efs_ceddda9d.PerformanceMode]:
         '''Set the performance mode of the EFS file system (Default: GENERAL_PURPOSE).'''
         result = self._values.get("efs_performance_mode")
-        return typing.cast(typing.Optional[aws_cdk.aws_efs.PerformanceMode], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_efs_ceddda9d.PerformanceMode], result)
 
     @builtins.property
-    def on_error(self) -> typing.Optional[aws_cdk.aws_lambda.IDestination]:
+    def on_error(self) -> typing.Optional[_aws_cdk_aws_lambda_ceddda9d.IDestination]:
         '''The Lambda Destination for files that fail to scan and are marked 'ERROR' or stuck 'IN PROGRESS' due to a Lambda timeout (Default: Creates and publishes to a new SQS queue if unspecified).'''
         result = self._values.get("on_error")
-        return typing.cast(typing.Optional[aws_cdk.aws_lambda.IDestination], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_lambda_ceddda9d.IDestination], result)
 
     @builtins.property
-    def on_result(self) -> typing.Optional[aws_cdk.aws_lambda.IDestination]:
+    def on_result(self) -> typing.Optional[_aws_cdk_aws_lambda_ceddda9d.IDestination]:
         '''The Lambda Destination for files marked 'CLEAN' or 'INFECTED' based on the ClamAV Virus scan or 'N/A' for scans triggered by S3 folder creation events marked (Default: Creates and publishes to a new Event Bridge Bus if unspecified).'''
         result = self._values.get("on_result")
-        return typing.cast(typing.Optional[aws_cdk.aws_lambda.IDestination], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_lambda_ceddda9d.IDestination], result)
 
     @builtins.property
     def reserved_concurrency(self) -> typing.Optional[jsii.Number]:
@@ -638,3 +606,55 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__ed8d91de6d3b1d3b5b25b039320198cf5ad1c0f9205948695f5a09421a986084(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    accept_responsibility_for_using_imported_bucket: typing.Optional[builtins.bool] = None,
+    buckets: typing.Optional[typing.Sequence[_aws_cdk_aws_s3_ceddda9d.IBucket]] = None,
+    defs_bucket_access_logs_config: typing.Optional[typing.Union[ServerlessClamscanLoggingProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    efs_encryption: typing.Optional[builtins.bool] = None,
+    efs_performance_mode: typing.Optional[_aws_cdk_aws_efs_ceddda9d.PerformanceMode] = None,
+    on_error: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.IDestination] = None,
+    on_result: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.IDestination] = None,
+    reserved_concurrency: typing.Optional[jsii.Number] = None,
+    scan_function_memory_size: typing.Optional[jsii.Number] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__3e814dc0b4006f620db601182ab2e1605421bf11a1ddd8d6862a3542134d7568(
+    bucket: _aws_cdk_aws_s3_ceddda9d.IBucket,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7810beb50932b9b83ee8c63bc62209567de654d2032fafbe7348d1b7415fa413(
+    bucket: _aws_cdk_aws_s3_ceddda9d.IBucket,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__c6710eb9eef2e9b05a93d9fba80fbf988499356d748d843afa0ab4772c40b9a4(
+    *,
+    logs_bucket: typing.Optional[typing.Union[builtins.bool, _aws_cdk_aws_s3_ceddda9d.IBucket]] = None,
+    logs_prefix: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__bcf16e4cfa40d24a942937d7d5ee19975f275f2c96366670b2ec79ce3f1a2213(
+    *,
+    accept_responsibility_for_using_imported_bucket: typing.Optional[builtins.bool] = None,
+    buckets: typing.Optional[typing.Sequence[_aws_cdk_aws_s3_ceddda9d.IBucket]] = None,
+    defs_bucket_access_logs_config: typing.Optional[typing.Union[ServerlessClamscanLoggingProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    efs_encryption: typing.Optional[builtins.bool] = None,
+    efs_performance_mode: typing.Optional[_aws_cdk_aws_efs_ceddda9d.PerformanceMode] = None,
+    on_error: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.IDestination] = None,
+    on_result: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.IDestination] = None,
+    reserved_concurrency: typing.Optional[jsii.Number] = None,
+    scan_function_memory_size: typing.Optional[jsii.Number] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
